@@ -116,7 +116,7 @@ namespace BOOM {
 
     // Fill the Vector with N(mu, sd^2) random numbers.
     Vector &randomize_gaussian(
-        double mean, double sd, RNG &rng = GlobalRng::rng);
+        double mean = 0.0, double sd = 1.0, RNG &rng = GlobalRng::rng);
 
     //-------------- STL vector stuff ---------------------
     double *data();
@@ -320,6 +320,9 @@ namespace BOOM {
   // prints to stdout.  This function is here so it can be called from gdb.
   void print(const Vector &v);
   void print_vector(const Vector &v);
+
+  // Print R code that can read in the vector values.
+  std::string to_Rstring(const Vector &v);
   std::istream &operator>>(std::istream &, Vector &);
   Vector read_Vector(std::istream &in);
 
