@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2011 Steven L. Scott
 
@@ -18,28 +19,24 @@
 
 #ifndef BOOM_FIXED_UNIVARIATE_SAMPLER_HPP_
 #define BOOM_FIXED_UNIVARIATE_SAMPLER_HPP_
-#include <Models/ParamTypes.hpp>
-#include <Models/PosteriorSamplers/PosteriorSampler.hpp>
-#include <cpputil/math_utils.hpp>
+#include "Models/ParamTypes.hpp"
+#include "Models/PosteriorSamplers/PosteriorSampler.hpp"
+#include "cpputil/math_utils.hpp"
 
-namespace BOOM{
-  class FixedUnivariateSampler : public PosteriorSampler{
+namespace BOOM {
+  class FixedUnivariateSampler : public PosteriorSampler {
    public:
-    FixedUnivariateSampler(Ptr<UnivParams> prm,
-                    double value,
-                    RNG &seeding_rng = GlobalRng::rng)
-        : PosteriorSampler(seeding_rng),
-          prm_(prm),
-          value_(value)
-    {}
+    FixedUnivariateSampler(const Ptr<UnivParams> &prm, double value,
+                           RNG &seeding_rng = GlobalRng::rng)
+        : PosteriorSampler(seeding_rng), prm_(prm), value_(value) {}
 
     void draw() override {
-      if(prm_->value() == value_) return;
+      if (prm_->value() == value_) return;
       prm_->set(value_);
     }
 
-    double logpri()const override{
-      if(prm_->value() == value_) return 0;
+    double logpri() const override {
+      if (prm_->value() == value_) return 0;
       return BOOM::negative_infinity();
     }
 
@@ -48,7 +45,6 @@ namespace BOOM{
     double value_;
   };
 
-}
+}  // namespace BOOM
 
-
-#endif //BOOM_FIXED_UNIVARIATE_SAMPLER_HPP_
+#endif  // BOOM_FIXED_UNIVARIATE_SAMPLER_HPP_
