@@ -43,7 +43,7 @@ namespace BOOM {
       return bM == (M + 1) * b0;  // factor of 'a' cancels
     }
 
-    void PBC::impose(Vector &b) const {
+    Vector & PBC::impose(Vector &b) const {
       uint b_sz = b.size();
       assert(b_sz >= 2);
       uint M = b_sz - 2;
@@ -56,6 +56,7 @@ namespace BOOM {
         b -= ad0;
         b.back() += ad0;
       }
+      return b;
     }
 
     Vector PBC::reduce(const Vector &b) const {
@@ -82,10 +83,11 @@ namespace BOOM {
       return (d[0] == 0.0 && d.sum() == 0.0);
     }
 
-    void PDC::impose(Vector &d) const {
+    Vector &PDC::impose(Vector &d) const {
       double d0 = d[0];
       d -= d0;
       d.back() -= d.sum();
+      return d;
     }
 
     Vector PDC::reduce(const Vector &d_full) const {
@@ -103,8 +105,6 @@ namespace BOOM {
       return ans;
     }
     //______________________________________________________________________
-    typedef UnivParams UP;
-    typedef ConstrainedVectorParams CVP;
 
     void PCR::setup() {
       set_abd_current();
@@ -122,7 +122,7 @@ namespace BOOM {
 
     void PCR::setup_beta() {
       uint M = maxscore();
-      if (d0_is_fixed) beta_ = new ConstrainedVectorParams(M + 2);
+      if (d0_is_fixed) beta_ = new ConstrainedVectorParams(Vector(M + 2));
       fill_beta(true);
       b_ = beta_->value();
     }
@@ -143,17 +143,17 @@ namespace BOOM {
     //______________________________________________________________________
     // constructors
 
-    Ptr<CVP> make_d_uint(uint Maxscore, bool id_d0);
-    Ptr<CVP> make_d_vec(const Vector &d, bool id_d0);
+    Ptr<ConstrainedVectorParams> make_d_uint(uint Maxscore, bool id_d0);
+    Ptr<ConstrainedVectorParams> make_d_vec(const Vector &d, bool id_d0);
 
-    Ptr<CVP> make_d_uint(uint Maxscore, bool id_d0) {
+    Ptr<ConstrainedVectorParams> make_d_uint(uint Maxscore, bool id_d0) {
       Vector d(Maxscore + 1, 0.0);
       return make_d_vec(d, id_d0);
     }
 
-    Ptr<CVP> make_d_vec(const Vector &d, bool id_d0) {
-      if (id_d0) return new CVP(d, new PcrDConstraint);
-      return new CVP(d, new SumConstraint(0.0));
+    Ptr<ConstrainedVectorParams> make_d_vec(const Vector &d, bool id_d0) {
+      if (id_d0) return new ConstrainedVectorParams(d, new PcrDConstraint);
+      return new ConstrainedVectorParams(d, new SumConstraint(0.0));
     }
 
     PCR::PartialCreditModel(const std::string &Id, uint Mscore, uint which_sub,
