@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
    Copyright (C) 2005 Steven L. Scott
 
@@ -13,11 +14,12 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+   USA
  */
 
-#include <cpputil/math_utils.hpp>
 #include <cmath>
-namespace BOOM{
-  double safelog(double x){ return x==0.0? negative_infinity() : log(x);}
-}
+#include "cpputil/math_utils.hpp"
+namespace BOOM {
+  double safelog(double x) { return x == 0.0 ? negative_infinity() : log(x); }
+}  // namespace BOOM
